@@ -27,7 +27,7 @@ Check the HTTP status for a resource.
 
 use 5.008;
 use vars qw($VERSION);
-$VERSION = '2.001';
+$VERSION = '2.002';
 
 use parent 'Test::Builder::Module';
 
@@ -97,8 +97,7 @@ sub _get_status {
 	return { status => NO_URL } unless defined $string;
 
 	my $url = Mojo::URL->new( $string );
-	return { result => INVALID_URL }
-		unless eval { $url->isa( 'Mojo::URL' ) };
+	return { status => undef } unless $url->host;
 
 	my $status = HTTP::SimpleLinkChecker::check_link( $url );
 
